@@ -1,13 +1,13 @@
 
-from optparse import Option
+
 import re
 import shlex
 import sqlparse
+import colemen_file_utils as cfu
 # # from sqlparse import sql
 import utils.string_format as format
-from utils.parse_utils import array_in_string
-import colemen_file_utils as cfu
-import utils.objectUtils as ou
+
+import utils.objectUtils as obj
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
 
 
@@ -86,7 +86,7 @@ def parse_key(value=None):
                 continue
             new_data[k] = v
 
-        print(new_data)
+        # print(new_data)
         output = new_data
     return output    
 
@@ -119,7 +119,7 @@ def parse_primary_key(value=None):
                 continue
             new_data[k] = v
 
-        print(new_data)
+        # print(new_data)
         output = new_data
     return output
 
@@ -164,7 +164,7 @@ def parse_constraint(value):
                 continue
             new_data[k] = v
 
-        print(new_data)
+        # print(new_data)
         output = new_data
     return output
 
@@ -353,6 +353,7 @@ def parse_allow_null(col_data):
         `method_name`: parse_allow_null
         @xxx [05-31-2022 07:31:12]: documentation for parse_allow_null
     '''
+    from utils.parse_utils import array_in_string
     nn_found = False
     for s in col_data['shlexed']:
         if array_in_string(["not null","NOT NULL"],s,False):
@@ -620,6 +621,35 @@ def parse_primary_keys(sql):
     return primary_keys
 
 def strip_sql_quotes(sql):
+    '''
+        Remove all quotes from an sql string.
+        This includes these characters:
+        - Double Quote - "
+        - Single Quote - '
+        - Accent/Tick  - `
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {str}
+            The string to strip of quotes.
+
+        Return {str}
+        ----------------------
+        The string without quotations.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 05-31-2022 11:56:37
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: strip_sql_quotes
+        @xxx [05-31-2022 11:58:02]: documentation for strip_sql_quotes
+    '''
+
+
     sql = sql.replace("'",'')
     sql = sql.replace('"','')
     sql = sql.replace('`','')
